@@ -142,10 +142,20 @@ var annotated_dup =
     [ "spa_audio_aec_info", "structspa__audio__aec__info.html", "structspa__audio__aec__info" ],
     [ "spa_audio_aec_methods", "structspa__audio__aec__methods.html", "structspa__audio__aec__methods" ],
     [ "spa_audio_info", "structspa__audio__info.html", "structspa__audio__info" ],
+    [ "spa_audio_info_aac", "structspa__audio__info__aac.html", "structspa__audio__info__aac" ],
+    [ "spa_audio_info_alac", "structspa__audio__info__alac.html", "structspa__audio__info__alac" ],
+    [ "spa_audio_info_amr", "structspa__audio__info__amr.html", "structspa__audio__info__amr" ],
+    [ "spa_audio_info_ape", "structspa__audio__info__ape.html", "structspa__audio__info__ape" ],
     [ "spa_audio_info_dsd", "structspa__audio__info__dsd.html", "structspa__audio__info__dsd" ],
     [ "spa_audio_info_dsp", "structspa__audio__info__dsp.html", "structspa__audio__info__dsp" ],
+    [ "spa_audio_info_flac", "structspa__audio__info__flac.html", "structspa__audio__info__flac" ],
     [ "spa_audio_info_iec958", "structspa__audio__info__iec958.html", "structspa__audio__info__iec958" ],
+    [ "spa_audio_info_mp3", "structspa__audio__info__mp3.html", "structspa__audio__info__mp3" ],
+    [ "spa_audio_info_opus", "structspa__audio__info__opus.html", "structspa__audio__info__opus" ],
+    [ "spa_audio_info_ra", "structspa__audio__info__ra.html", "structspa__audio__info__ra" ],
     [ "spa_audio_info_raw", "structspa__audio__info__raw.html", "structspa__audio__info__raw" ],
+    [ "spa_audio_info_vorbis", "structspa__audio__info__vorbis.html", "structspa__audio__info__vorbis" ],
+    [ "spa_audio_info_wma", "structspa__audio__info__wma.html", "structspa__audio__info__wma" ],
     [ "spa_audio_layout_info", "structspa__audio__layout__info.html", "structspa__audio__layout__info" ],
     [ "spa_buffer", "structspa__buffer.html", "structspa__buffer" ],
     [ "spa_buffer_alloc_info", "structspa__buffer__alloc__info.html", "structspa__buffer__alloc__info" ],
@@ -160,6 +170,8 @@ var annotated_dup =
     [ "spa_dbus_connection", "structspa__dbus__connection.html", "structspa__dbus__connection" ],
     [ "spa_dbus_connection_events", "structspa__dbus__connection__events.html", "structspa__dbus__connection__events" ],
     [ "spa_dbus_methods", "structspa__dbus__methods.html", "structspa__dbus__methods" ],
+    [ "spa_debug_context", "structspa__debug__context.html", "structspa__debug__context" ],
+    [ "spa_debug_log_ctx", "structspa__debug__log__ctx.html", "structspa__debug__log__ctx" ],
     [ "spa_device", "structspa__device.html", "structspa__device" ],
     [ "spa_device_events", "structspa__device__events.html", "structspa__device__events" ],
     [ "spa_device_info", "structspa__device__info.html", "structspa__device__info" ],
@@ -217,6 +229,7 @@ var annotated_dup =
     [ "spa_meta_cursor", "structspa__meta__cursor.html", "structspa__meta__cursor" ],
     [ "spa_meta_header", "structspa__meta__header.html", "structspa__meta__header" ],
     [ "spa_meta_region", "structspa__meta__region.html", "structspa__meta__region" ],
+    [ "spa_meta_videotransform", "structspa__meta__videotransform.html", "structspa__meta__videotransform" ],
     [ "spa_node", "structspa__node.html", "structspa__node" ],
     [ "spa_node_callbacks", "structspa__node__callbacks.html", "structspa__node__callbacks" ],
     [ "spa_node_events", "structspa__node__events.html", "structspa__node__events" ],
@@ -271,6 +284,7 @@ var annotated_dup =
     [ "spa_result_node_params_data", "structspa__result__node__params__data.html", "structspa__result__node__params__data" ],
     [ "spa_ringbuffer", "structspa__ringbuffer.html", "structspa__ringbuffer" ],
     [ "spa_source", "structspa__source.html", "structspa__source" ],
+    [ "spa_strbuf", "structspa__strbuf.html", "structspa__strbuf" ],
     [ "spa_support", "structspa__support.html", "structspa__support" ],
     [ "spa_system", "structspa__system.html", "structspa__system" ],
     [ "spa_system_methods", "structspa__system__methods.html", "structspa__system__methods" ],
