@@ -27,5 +27,6 @@ var group__pw__metadata =
     [ "pw_metadata_add_listener", "group__pw__metadata.html#ga69cd4c94d8630f838be17fb298e287ef", null ],
     [ "pw_metadata_set_property", "group__pw__metadata.html#ga0021965e39d587fccd9e0390f4f2f3f3", null ],
     [ "pw_metadata_clear", "group__pw__metadata.html#gaa690d58ed6185add131dbb88976b54ef", null ],
-    [ "PW_KEY_METADATA_NAME", "group__pw__metadata.html#gaef9f80c524a01f3883aff5180e5c2c81", null ]
+    [ "PW_KEY_METADATA_NAME", "group__pw__metadata.html#gaef9f80c524a01f3883aff5180e5c2c81", null ],
+    [ "PW_KEY_METADATA_VALUES", "group__pw__metadata.html#ga218b41ed7bec1ddda1940f43f53d21ab", null ]
 ];
\ No newline at end of file
