@@ -6,6 +6,10 @@ var group__pw__properties =
       [ "flags", "structpw__properties.html#a8003e978689f764bb7bd2a3ab2d46a87", null ]
     ] ],
     [ "PW_PROPERTIES_FLAG_NL", "group__pw__properties.html#gab1c1ac34b138a20ee21b5b4647dfe24a", null ],
+    [ "PW_PROPERTIES_FLAG_RECURSE", "group__pw__properties.html#gad81dddbf98b681b6e9d672041782c5f3", null ],
+    [ "PW_PROPERTIES_FLAG_ENCLOSE", "group__pw__properties.html#ga51237cc8ccfa0a84a7df25800e962731", null ],
+    [ "PW_PROPERTIES_FLAG_ARRAY", "group__pw__properties.html#ga8a98fcda5b4eb3d7aeb0daaacefc9b6c", null ],
+    [ "PW_PROPERTIES_FLAG_COLORS", "group__pw__properties.html#gaad20740b131f615b1c143a06f15ef976", null ],
     [ "pw_properties_new", "group__pw__properties.html#ga1b4b83cd7ff56bdcabc3419f3a40eb95", null ],
     [ "pw_properties_new_dict", "group__pw__properties.html#ga5430d66a13acaee2e5bac67d32e48c73", null ],
     [ "pw_properties_new_string", "group__pw__properties.html#ga7bedc63c78dfe152e866dc518424f299", null ],
