@@ -4,7 +4,8 @@ var group__pw__stream =
     [ "pw_buffer", "structpw__buffer.html", [
       [ "buffer", "structpw__buffer.html#ad0716b5bc3f7e1cb3009c524c0192090", null ],
       [ "user_data", "structpw__buffer.html#ad85549808ad885c57f85e1aee60b8c96", null ],
-      [ "size", "structpw__buffer.html#a925734b861209896789573f3b94a61c1", null ]
+      [ "size", "structpw__buffer.html#a925734b861209896789573f3b94a61c1", null ],
+      [ "requested", "structpw__buffer.html#ab5fe741ec31686febdbc602098945f08", null ]
     ] ],
     [ "pw_stream_control", "structpw__stream__control.html", [
       [ "flags", "structpw__stream__control.html#a4167f3df47a2d2deff793d3f1f6d31d2", null ],
@@ -20,7 +21,10 @@ var group__pw__stream =
       [ "rate", "structpw__time.html#a41d793c390eefc6aee165e16e0d7c898", null ],
       [ "ticks", "structpw__time.html#a99e3d7963e24fbf410afa03c73465328", null ],
       [ "delay", "structpw__time.html#a1ea3fa77ce4221df0d5ac3ad8fd1f6c7", null ],
-      [ "queued", "structpw__time.html#a91dafbb38397328f8705e2bb20b7625a", null ]
+      [ "queued", "structpw__time.html#a91dafbb38397328f8705e2bb20b7625a", null ],
+      [ "buffered", "structpw__time.html#a4ad8ba0afa44dc283d8ecd5ea1e9d0ff", null ],
+      [ "queued_buffers", "structpw__time.html#a92d7a1849d4dc044d2fa64bd35a7a57d", null ],
+      [ "avail_buffers", "structpw__time.html#aebd42745267531bc23e1ee34dd759607", null ]
     ] ],
     [ "pw_stream_events", "structpw__stream__events.html", [
       [ "version", "structpw__stream__events.html#a74aaca4c31e44dad69aba50607055419", null ],
@@ -73,8 +77,10 @@ var group__pw__stream =
     [ "pw_stream_disconnect", "group__pw__stream.html#gaa727d7a41acb9d0ec574f93f01328d30", null ],
     [ "pw_stream_set_error", "group__pw__stream.html#ga19f542ff2b8a51336ae78cfaec8ed896", null ],
     [ "pw_stream_update_params", "group__pw__stream.html#ga0c274f28a9b9b2fe286719db159f166b", null ],
+    [ "pw_stream_set_param", "group__pw__stream.html#ga97c613bc4ea822bfbbce0de6ab1b9042", null ],
     [ "pw_stream_get_control", "group__pw__stream.html#ga8a3e7ddb0e61c4266ce735a085adb5e7", null ],
     [ "pw_stream_set_control", "group__pw__stream.html#ga2d5e07833039ac7a202caaf297556f52", null ],
+    [ "pw_stream_get_time_n", "group__pw__stream.html#gadde95a60798bfffa6575306bc07ee7f4", null ],
     [ "pw_stream_get_time", "group__pw__stream.html#ga721dc4d5ec4c406ecb0469bfefea468f", null ],
     [ "pw_stream_dequeue_buffer", "group__pw__stream.html#ga0ed34dd74ca8f5f46db7c2a4cbd45a94", null ],
     [ "pw_stream_queue_buffer", "group__pw__stream.html#gabe1c593f34080ea9c8c6231abe4e7386", null ],
