@@ -1,5 +1,14 @@
 var NAVTREEINDEX15 =
 {
+"group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635af25926b5d489ddd2acb63ea263c78e92":[10,8,8,12,22,44],
+"group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635af64dcbfbabdf6f2529ab10eee233a25f":[10,8,8,12,22,26],
+"group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635afae023d5557f54aad58d6690a3098752":[10,8,8,12,22,14],
+"group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635aff40c8f7d5f7228694ad59007df53867":[10,8,8,12,22,38],
+"group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635affe6056769241bea4ffa3e785e5e401b":[10,8,8,12,22,0],
+"group__spa__utils.html":[10,8,8],
+"group__spa__utils__defs.html":[10,8,8,1],
+"group__spa__utils__defs.html#ga006941b3f6423cec7b170b4434d8a799":[10,8,8,1,8],
+"group__spa__utils__defs.html#ga007f98725701a4b6debe365c7a5e0bbe":[10,8,8,1,82],
 "group__spa__utils__defs.html#ga01ba22304e834c86556e645614f65d84":[10,8,8,1,56],
 "group__spa__utils__defs.html#ga06647c110a0382a09bea681a14634f64":[10,8,8,1,20],
 "group__spa__utils__defs.html#ga0fb5b0492ff8bb640cbad9b2711c77d0":[10,8,8,1,64],
@@ -205,14 +214,15 @@ var NAVTREEINDEX15 =
 "page_man_pipewire_pulse_1.html":[5,12,1],
 "page_man_pw_cat_1.html":[5,12,3],
 "page_man_pw_cli_1.html":[5,12,4],
-"page_man_pw_dot_1.html":[5,12,5],
-"page_man_pw_jack_1.html":[5,12,12],
-"page_man_pw_link_1.html":[5,12,6],
-"page_man_pw_metadata_1.html":[5,12,7],
-"page_man_pw_mididump_1.html":[5,12,8],
-"page_man_pw_mon_1.html":[5,12,9],
-"page_man_pw_profiler_1.html":[5,12,10],
-"page_man_pw_top_1.html":[5,12,11],
+"page_man_pw_config_1.html":[5,12,5],
+"page_man_pw_dot_1.html":[5,12,6],
+"page_man_pw_jack_1.html":[5,12,13],
+"page_man_pw_link_1.html":[5,12,7],
+"page_man_pw_metadata_1.html":[5,12,8],
+"page_man_pw_mididump_1.html":[5,12,9],
+"page_man_pw_mon_1.html":[5,12,10],
+"page_man_pw_profiler_1.html":[5,12,11],
+"page_man_pw_top_1.html":[5,12,12],
 "page_midi.html":[5,7],
 "page_midi.html#autotoc_md20":[5,7,0],
 "page_midi.html#autotoc_md21":[5,7,0,0],
@@ -239,15 +249,5 @@ var NAVTREEINDEX15 =
 "page_module_fallback_sink.html":[6,9],
 "page_module_filter_chain.html":[6,10],
 "page_module_link_factory.html":[6,11],
-"page_module_loopback.html":[6,12],
-"page_module_metadata.html":[6,13],
-"page_module_pipe_tunnel.html":[6,14],
-"page_module_portal.html":[6,15],
-"page_module_profiler.html":[6,16],
-"page_module_protocol_native.html":[6,17],
-"page_module_protocol_pulse.html":[6,18],
-"page_module_protocol_simple.html":[6,19],
-"page_module_pulse_tunnel.html":[6,20],
-"page_module_raop_discover.html":[6,22],
-"page_module_raop_sink.html":[6,21]
+"page_module_loopback.html":[6,12]
 };
