@@ -1,5 +1,15 @@
 var NAVTREEINDEX16 =
 {
+"page_module_metadata.html":[6,13],
+"page_module_pipe_tunnel.html":[6,14],
+"page_module_portal.html":[6,15],
+"page_module_profiler.html":[6,16],
+"page_module_protocol_native.html":[6,17],
+"page_module_protocol_pulse.html":[6,18],
+"page_module_protocol_simple.html":[6,19],
+"page_module_pulse_tunnel.html":[6,20],
+"page_module_raop_discover.html":[6,22],
+"page_module_raop_sink.html":[6,21],
 "page_module_roc_sink.html":[6,23],
 "page_module_roc_source.html":[6,24],
 "page_module_rt.html":[6,29],
@@ -239,15 +249,5 @@ var NAVTREEINDEX16 =
 "structpw__buffers.html#af915317f3448e471390a13c48c0d873e":[10,5,9,1,0],
 "structpw__client.html":[10,4,3,4],
 "structpw__client__endpoint.html":[10,7,4,22],
-"structpw__client__endpoint__events.html":[10,7,4,6],
-"structpw__client__endpoint__events.html#a02d8f4d9cd9f898d3109a64f7afd81e1":[10,7,4,6,4],
-"structpw__client__endpoint__events.html#a12f427748eebbfd39cdc4f75a9db57ed":[10,7,4,6,1],
-"structpw__client__endpoint__events.html#a43e06e14ba4461922bfce4c3c98c13f1":[10,7,4,6,3],
-"structpw__client__endpoint__events.html#a45e7bb70eb2b24c33aad0c82dcf001b6":[10,7,4,6,2],
-"structpw__client__endpoint__events.html#afab781a09b218afdc2c9ffb54502be5e":[10,7,4,6,0],
-"structpw__client__endpoint__methods.html":[10,7,4,7],
-"structpw__client__endpoint__methods.html#a283f6ec14d1a3ff9b0b0aa213b2ea850":[10,7,4,7,1],
-"structpw__client__endpoint__methods.html#a58fe2e1f1524cf0f22dda84f7f9c33e0":[10,7,4,7,0],
-"structpw__client__events.html":[10,4,3,2],
-"structpw__client__events.html#a0ceb2ae8884ca4a30bae720198410075":[10,4,3,2,0]
+"structpw__client__endpoint__events.html":[10,7,4,6]
 };
