@@ -1,5 +1,15 @@
 var NAVTREEINDEX19 =
 {
+"structpw__proxy__events.html":[10,4,13,1],
+"structpw__proxy__events.html#a1d91d77027018205abcdfe5f25b0feb1":[10,4,13,1,4],
+"structpw__proxy__events.html#a220d199c1f0a241f1e623686863e8158":[10,4,13,1,6],
+"structpw__proxy__events.html#a25e8553fd0ed2f729ffe61994f6973a2":[10,4,13,1,0],
+"structpw__proxy__events.html#a8072b9d1ea7e1c91cce89de75d1c7e61":[10,4,13,1,3],
+"structpw__proxy__events.html#a8916a9be2fa3763221fdf64f79468d14":[10,4,13,1,2],
+"structpw__proxy__events.html#aaa8802aa5a62fdc422f8db0d606adac3":[10,4,13,1,1],
+"structpw__proxy__events.html#af8e0510a58d92ddd0831293e1c42b867":[10,4,13,1,5],
+"structpw__registry.html":[10,4,4,5],
+"structpw__registry__events.html":[10,4,14,1],
 "structpw__registry__events.html#a04c4f7cbbf5dcc0c54887862887dbc97":[10,4,14,1,2],
 "structpw__registry__events.html#a37bd7089a7a07d7154e111e67b25f96c":[10,4,14,1,1],
 "structpw__registry__events.html#a94464d7de86207e80a3dff93974b1a01":[10,4,14,1,0],
@@ -92,6 +102,7 @@ var NAVTREEINDEX19 =
 "structspa__audio__aec__methods.html#a0ea3331fe5e9ceed6a0969c4f2aaa4c3":[11,0,140,4],
 "structspa__audio__aec__methods.html#a1d1c3a7ec1bd783ddb3cea31bc421cb1":[11,0,140,6],
 "structspa__audio__aec__methods.html#a5b18f9a4430576c06bf7067a61a97854":[11,0,140,5],
+"structspa__audio__aec__methods.html#a73977fea4b6c069260af4f16b08ceee0":[11,0,140,10],
 "structspa__audio__aec__methods.html#aa75447be29ace8e48fefb525ed44bcd8":[11,0,140,7],
 "structspa__audio__aec__methods.html#aadf3db584c3062de5a2af134e6d7014d":[11,0,140,3],
 "structspa__audio__aec__methods.html#af6f30eee3a6af553b3e6ef83f850a691":[11,0,140,0],
@@ -238,16 +249,5 @@ var NAVTREEINDEX19 =
 "structspa__dbus__methods.html#a6e090fa6083fa425460f631ea48c3434":[10,8,9,1,4,0],
 "structspa__debug__context.html":[10,8,3,9],
 "structspa__debug__context.html#a5d5a27395a63043da36af7b1289cc711":[10,8,3,9,0],
-"structspa__debug__log__ctx.html":[10,8,3,10],
-"structspa__debug__log__ctx.html#a283294f711d9752bb65c8c09e5a06724":[10,8,3,10,6],
-"structspa__debug__log__ctx.html#a49ae612d5a9f8abff00d338e0f42f338":[10,8,3,10,5],
-"structspa__debug__log__ctx.html#a7834e2a074032895d9760015da193685":[10,8,3,10,1],
-"structspa__debug__log__ctx.html#a7ef044cf8f043c056c0f09e7dc52772f":[10,8,3,10,2],
-"structspa__debug__log__ctx.html#a89c265ff2c1860bc78cb3a71e016c44a":[10,8,3,10,0],
-"structspa__debug__log__ctx.html#abcfc47fb7d6acf39603b9a1547edd1e7":[10,8,3,10,4],
-"structspa__debug__log__ctx.html#afcdc7fd8504c905b64485893b6816ee2":[10,8,3,10,3],
-"structspa__device.html":[10,8,4,3],
-"structspa__device.html#a00d8f19734c35525e99ecaab33113d3f":[10,8,4,3,0],
-"structspa__device__events.html":[10,8,4,7],
-"structspa__device__events.html#a0b9ba211d7f484c7df9ac269d5b49af3":[10,8,4,7,2]
+"structspa__debug__log__ctx.html":[10,8,3,10]
 };
