@@ -9,5 +9,6 @@ var structspa__audio__aec__methods =
     [ "deactivate", "structspa__audio__aec__methods.html#a1d1c3a7ec1bd783ddb3cea31bc421cb1", null ],
     [ "enum_props", "structspa__audio__aec__methods.html#aa75447be29ace8e48fefb525ed44bcd8", null ],
     [ "get_params", "structspa__audio__aec__methods.html#a028adaf84c4fb5c19e416c53874ad57f", null ],
-    [ "set_params", "structspa__audio__aec__methods.html#af75957ae10a92bb2253df67aa6eca97f", null ]
+    [ "set_params", "structspa__audio__aec__methods.html#af75957ae10a92bb2253df67aa6eca97f", null ],
+    [ "init2", "structspa__audio__aec__methods.html#a73977fea4b6c069260af4f16b08ceee0", null ]
 ];
\ No newline at end of file
